@@ -9,7 +9,6 @@ def api_v4(self):
     user_load_balancers(self)
     user_load_balancing_analytics(self)
     user_tokens_verify(self)
-    user_virtual_dns(self)
     user_workers(self)
 
     # The API commands for /zones/
@@ -35,11 +34,6 @@ def api_v4(self):
     # The API commands for /railguns/
     railguns(self)
 
-    # The API commands for /organizations/
-    organizations(self)
-    organizations_audit_logs(self)
-    organizations_virtual_dns(self)
-
     # The API commands for /certificates/
     certificates(self)
 
@@ -85,7 +79,7 @@ def zones(self):
     self.add('VOID', "zones", "access")
     self.add('AUTH', "zones", "access/apps")
     self.add('AUTH', "zones", "access/apps/policies")
-    self.add('AUTH', "zones", "access/apps/revoke-tokens")
+    self.add('AUTH', "zones", "access/apps", "revoke-tokens")
     self.add('AUTH', "zones", "access/certificates")
     self.add('AUTH', "zones", "activation_check")
     self.add('AUTH', "zones", "available_plans")
@@ -234,23 +228,6 @@ def railguns(self):
     self.add('AUTH', "railguns")
     self.add('AUTH', "railguns", "zones")
 
-def organizations(self):
-    """ API core commands for Cloudflare API"""
-
-    self.add('AUTH', "organizations")
-    self.add('AUTH', "organizations", "members")
-    self.add('AUTH', "organizations", "invites")
-    self.add('AUTH', "organizations", "railguns")
-    self.add('AUTH', "organizations", "railguns", "zones")
-    self.add('AUTH', "organizations", "roles")
-    self.add('VOID', "organizations", "firewall")
-    self.add('VOID', "organizations", "firewall/access_rules")
-    self.add('AUTH', "organizations", "firewall/access_rules/rules")
-    self.add('VOID', "organizations", "load_balancers")
-    self.add('AUTH', "organizations", "load_balancers/monitors")
-    self.add('AUTH', "organizations", "load_balancers/pools")
-    self.add('AUTH', "organizations", "load_balancers/pools", "health")
-
 def certificates(self):
     """ API core commands for Cloudflare API"""
 
@@ -336,28 +313,12 @@ def user_load_balancers(self):
     self.add('AUTH', "user/load_balancers/pools", "health")
     self.add('AUTH', "user/load_balancers/pools", "preview")
 
-def user_virtual_dns(self):
-    """ API core commands for Cloudflare API"""
-
-    self.add('AUTH', "user/virtual_dns")
-    self.add('VOID', "user/virtual_dns", "dns_analytics")
-    self.add('AUTH', "user/virtual_dns", "dns_analytics/report")
-    self.add('AUTH', "user/virtual_dns", "dns_analytics/report/bytime")
-
 def user_workers(self):
     """ API core commands for Cloudflare API"""
 
     self.add('VOID', "user/workers")
     self.add('AUTH', "user/workers/scripts")
 
-def organizations_virtual_dns(self):
-    """ API core commands for Cloudflare API"""
-
-    self.add('AUTH', "organizations", "virtual_dns")
-    self.add('VOID', "organizations", "virtual_dns", "dns_analytics")
-    self.add('AUTH', "organizations", "virtual_dns", "dns_analytics/report")
-    self.add('AUTH', "organizations", "virtual_dns", "dns_analytics/report/bytime")
-
 def user_audit_logs(self):
     """ API core commands for Cloudflare API"""
 
@@ -378,11 +339,6 @@ def user_tokens_verify(self):
     self.add('AUTH', "user/tokens/verify")
     self.add('AUTH', "user/tokens", "value")
 
-def organizations_audit_logs(self):
-    """ API core commands for Cloudflare API"""
-
-    self.add('AUTH', "organizations", "audit_logs")
-
 def accounts(self):
     """ API core commands for Cloudflare API"""
 
@@ -412,7 +368,7 @@ def accounts(self):
     self.add('VOID', 'accounts', 'rules')
     self.add('AUTH', 'accounts', 'rules/lists')
     self.add('AUTH', 'accounts', 'rules/lists', 'items')
-    self.add('AUTH', 'accounts', 'rules/lists/bulk-operations')
+    self.add('AUTH', 'accounts', 'rules/lists/bulk_operations')
     self.add('VOID', "accounts", "storage")
     self.add('AUTH', "accounts", "storage/analytics")
     self.add('AUTH', "accounts", "storage/analytics/stored")
