@@ -37,8 +37,11 @@ class CloudFlare(object):
                 self.certtoken = config['certtoken']
             else:
                 self.certtoken = None
-
-            self.base_url = config['base_url']
+            if 'base_url' in config:
+                self.base_url = config['base_url']
+            else:
+                # We must have a base_url value
+                self.base_url = BASE_URL
             self.raw = config['raw']
             self.use_sessions = config['use_sessions']
             self.profile = config['profile']
@@ -852,14 +855,20 @@ class CloudFlare(object):
         branch = self
         for element in a[0:-1]:
             try:
-                branch = getattr(branch, element)
+                if '-' in element:
+                    branch = getattr(element, element.replace('-','_'))
+                else:
+                    branch = getattr(branch, element)
             except:
                 # should never happen
                 raise CloudFlareAPIError(0, 'api load name failed')
         name = a[-1]
 
         try:
-            f = getattr(branch, name)
+            if '-' in name:
+                f = getattr(element, name.replace('-','_'))
+            else:
+                f = getattr(branch, name)
             # already exists - don't let it overwrite
             raise CloudFlareAPIError(0, 'api duplicate name found: %s/**%s**' % ('/'.join(a[0:-1]), name))
         except AttributeError:
@@ -880,7 +889,11 @@ class CloudFlare(object):
             # should never happen
             raise CloudFlareAPIError(0, 'api load type mismatch')
 
-        setattr(branch, name, f)
+        if '-' in name:
+            # dashes (vs underscores) cause issues in Python and other languages
+            setattr(branch, name.replace('-','_'), f)
+        else:
+            setattr(branch, name, f)
 
     def api_list(self, m=None, s=''):
         """recursive walk of the api tree returning a list of api calls"""
@@ -901,7 +914,8 @@ class CloudFlare(object):
                 if 'delete' in d or 'get' in d or 'patch' in d or 'post' in d or 'put' in d:
                     # only show the result if a call exists for this part
                     if '_parts' in d:
-                        w.append(s + '/' + n)
+                        # handle underscores by returning the actual API call vs the method name
+                        w.append(str(a)[1:-1].replace('/:id/','/'))
                 w = w + self.api_list(a, s + '/' + n)
         return w
 
@@ -910,11 +924,9 @@ class CloudFlare(object):
 
         return api_decode_from_web(self._base._api_from_web())
 
-    def __init__(self, email=None, token=None, certtoken=None, debug=False, raw=False, use_sessions=True, profile=None):
+    def __init__(self, email=None, token=None, certtoken=None, debug=False, raw=False, use_sessions=True, profile=None, base_url=None):
         """ Cloudflare v4 API"""
 
-        base_url = BASE_URL
-
         try:
             config = read_configs(profile)
         except:
